==> r2r-3.2.35-py3-none-any.whl: core/base/providers/__init__.py <==
from .auth import AuthConfig, AuthProvider
from .base import AppConfig, Provider, ProviderConfig
from .crypto import CryptoConfig, CryptoProvider
from .database import (
    CollectionHandler,
    DatabaseConfig,
    DatabaseConnectionManager,
    DatabaseProvider,
    DocumentHandler,
    FileHandler,
    KGHandler,
    LoggingHandler,
    PostgresConfigurationSettings,
    PromptHandler,
    TokenHandler,
    UserHandler,
    VectorHandler,
)
from .embedding import EmbeddingConfig, EmbeddingProvider
from .ingestion import ChunkingStrategy, IngestionConfig, IngestionProvider
from .llm import CompletionConfig, CompletionProvider
from .orchestration import OrchestrationConfig, OrchestrationProvider, Workflow

__all__ = [
    # Auth provider
    "AuthConfig",
    "AuthProvider",
    # Base provider classes
    "AppConfig",
    "Provider",
    "ProviderConfig",
    # Ingestion provider
    "IngestionConfig",
    "IngestionProvider",
    "ChunkingStrategy",
    # Crypto provider
    "CryptoConfig",
    "CryptoProvider",
    # Database providers
    "DatabaseConnectionManager",
    "DocumentHandler",
    "CollectionHandler",
    "TokenHandler",
    "UserHandler",
    "LoggingHandler",
    "VectorHandler",
    "KGHandler",
    "PromptHandler",
    "FileHandler",
    "DatabaseConfig",
    "PostgresConfigurationSettings",
    "DatabaseProvider",
    # Embedding provider
    "EmbeddingConfig",
    "EmbeddingProvider",
    # LLM provider
    "CompletionConfig",
    "CompletionProvider",
    # Orchestration provider
    "OrchestrationConfig",
    "OrchestrationProvider",
    "Workflow",
]

==> r2r-3.5.6-py3-none-any.whl: core/base/providers/__init__.py <==
from .auth import AuthConfig, AuthProvider
from .base import AppConfig, Provider, ProviderConfig
from .crypto import CryptoConfig, CryptoProvider
from .database import (
    DatabaseConfig,
    DatabaseConnectionManager,
    DatabaseProvider,
    Handler,
    LimitSettings,
    PostgresConfigurationSettings,
)
from .email import EmailConfig, EmailProvider
from .embedding import EmbeddingConfig, EmbeddingProvider
from .ingestion import (
    ChunkingStrategy,
    IngestionConfig,
    IngestionMode,
    IngestionProvider,
)
from .llm import CompletionConfig, CompletionProvider
from .orchestration import OrchestrationConfig, OrchestrationProvider, Workflow
from .scheduler import SchedulerConfig, SchedulerProvider

__all__ = [
    # Auth provider
    "AuthConfig",
    "AuthProvider",
    # Base provider classes
    "AppConfig",
    "Provider",
    "ProviderConfig",
    # Ingestion provider
    "IngestionMode",
    "IngestionConfig",
    "IngestionProvider",
    "ChunkingStrategy",
    # Crypto provider
    "CryptoConfig",
    "CryptoProvider",
    # Email provider
    "EmailConfig",
    "EmailProvider",
    # Database providers
    "DatabaseConnectionManager",
    "DatabaseConfig",
    "LimitSettings",
    "PostgresConfigurationSettings",
    "DatabaseProvider",
    "Handler",
    # Embedding provider
    "EmbeddingConfig",
    "EmbeddingProvider",
    # LLM provider
    "CompletionConfig",
    "CompletionProvider",
    # Orchestration provider
    "OrchestrationConfig",
    "OrchestrationProvider",
    "Workflow",
    # Scheduler provider
    "SchedulerConfig",
    "SchedulerProvider",
]
